#
# spec file for package libxml2 (Version 2.6.30)
#
# Copyright (c) 2007 SUSE LINUX Products GmbH, Nuernberg, Germany.
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

Name:           libxml2
BuildRequires:  readline-devel zlib-devel
License:        X11/MIT
Group:          System/Libraries
AutoReqProv:    on
Summary:        A Library to Manipulate XML Files
Version:        2.6.30
Release:        6.3
Source:         %{name}-%{version}.tar.bz2
Patch0:         %{name}-2.6.29-printf.patch
Patch1:         %{name}-2.6.29-gcc4.patch
Patch2:         %{name}-2.6.29-hppa.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://xmlsoft.org

%description
The XML C library was initially developed for the GNOME project. It is
now used by many programs to load and save extensible data structures
or manipulate any kind of XML files.

This library implements a number of existing standards related to
markup languages, including the XML standard, name spaces in XML, XML
Base, RFC 2396, XPath, XPointer, HTML4, XInclude, SGML catalogs, and
XML catalogs. In most cases, libxml tries to implement the
specification in a rather strict way. To some extent, it provides
support for the following specifications, but does not claim to
implement them: DOM, FTP client, HTTP client, and SAX.

The library also supports RelaxNG. Support for W3C XML Schemas is in
progress.



Authors:
--------
    Daniel Veillard <Daniel.Veillard@imag.fr>
    Alejandro Forero <bachue@bachue.com>
    Chris Lahey <clahey@umich.edu>
    Christopher Blizzard <blizzard@appliedtheory.com>
    James Henstridge <james@daa.com.au>
    Jody Goldberg <jgoldberg@home.com>
    Manish Vachharajani <mvachhar@vger.rutgers.edu>
    Martin Baulig <baulig@suse.de>
    Michael Meeks <michael@edenproject.org>
    Miguel de Icaza <miguel@nuclecu.unam.mx>
    Nuno Ferreira <nmrf@rnl.ist.utl.pt>
    Raja R Harinath <harinath@cs.umn.edu>
    Ramiro Estrugo <ramiro@eazel.com>
    Raph Levien <raph@acm.org>
    Sven Heinicke <sven@zen.org>
    Timur Bakeyev <mc@bat.ru>
    Tomasz K&#322;oczko <kloczek@pld.org.pl>
    Tom Tromey <tromey@cygnus.com>

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
AutoReqProv:    on
Requires:       %{name} = %{version}
Requires:       zlib-devel readline-devel
Requires:       glibc-devel

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.



Authors:
--------
    cf. libxml2.

%prep
%setup -q
%patch0
%patch1
%patch2

%build
# workaround for #310196
%ifarch s390 s390x
export RPM_OPT_FLAGS=${RPM_OPT_FLAGS/-O2/-O1}
%endif
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
%configure \
    --with-html-dir=%{_datadir}/doc \
    --with-fexceptions \
    --with-history \
    --enable-ipv6
make %{?jobs:-j%jobs}

%check
# make check

%install
make DESTDIR=$RPM_BUILD_ROOT install
# Unwanted doc stuff
rm -fr $RPM_BUILD_ROOT%{_datadir}/doc
rm -fr $RPM_BUILD_ROOT%{_datadir}/gtk-doc
rm -fr $RPM_BUILD_ROOT%{_libdir}/python*
# don't package examples [n#51382]
make -C example clean
rm -fr example/.deps
make -C doc/examples clean
rm -fr doc/examples/.deps
ln -s %{_includedir}/libxml2/libxml $RPM_BUILD_ROOT%{_includedir}/libxml
chmod +x $RPM_BUILD_ROOT%{_libdir}/lib*.so.*

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%doc AUTHORS NEWS README COPYING* Copyright TODO
%doc %{_mandir}/man1/xmllint.1*
%doc %{_mandir}/man1/xmlcatalog.1*
%{_libdir}/lib*.so.*
%{_bindir}/xmllint
%{_bindir}/xmlcatalog

%files devel
%defattr(-, root, root)
%doc doc/*.{html,gif,png}
%doc doc/html
%doc doc/tutorial
%doc doc/devhelp
%doc doc/examples
%doc example
%doc %{_mandir}/man1/xml2-config.1*
%doc %{_mandir}/man3/libxml.3*
%{_libdir}/lib*.so
%{_libdir}/*a
%{_libdir}/*.sh
%{_bindir}/xml2-config
%{_prefix}/include/libxml
%{_prefix}/include/libxml2
%{_libdir}/pkgconfig/*
%{_datadir}/aclocal/libxml.m4

%changelog
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 2.6.30:
  * Portability: Solaris crash on error handling, windows path
    fixes, mingw build
  * Bugfixes: xmlXPathNodeSetSort problem, leak when reusing a
    writer for a new document, Schemas xsi:nil handling patch,
    relative URI build problem, crash in xmlDocFormatDump, invalid
    char in comment detection bug, fix disparity with
    xmlSAXUserParseMemory, automata generation for complex regexp
    counts problems, Schemas IDC import problems, xpath predicate
    evailation error handling
* Thu Sep 13 2007 dmueller@suse.de
- build on s390x
* Tue Aug 28 2007 prusnak@suse.cz
- applied some fixes from 2.6.30 to fix regression that prevents
  the documentation from updating to Beta2 [#300675]
  (up30.patch)
* Wed Jun 13 2007 prusnak@suse.cz
- updated to 2.6.29:
  o bug fixes:
  * fixed xmlBufferAdd problem
  * regexp interpretation of '\'
  * XPath number serialization
  * nanohttp gzipped stream fix
  * uri bug
  * XPath string value of PI nodes
  * XPath node set sorting bugs
  * avoid outputting namespace decl dups in the writer
  * xmlCtxtReset bug
  * UTF-8 encoding error handling
  * recustion on next in catalogs
  * Relax-NG crash
  * invalid character in attribute detection bug
  o improved:
  * keep URI query parts in raw form
  * embed tag support in HTML
- dropped obsolete patches:
  * pinode.patch (included in update)
* Thu May 31 2007 prusnak@suse.cz
- fixed problem with xpath's string-value for a PI node
  with no content (pinode.path) [#278173]
- cleaned spec file
* Tue Apr 24 2007 prusnak@suse.cz
- updated to 2.6.28:
  o bug fixes:
  * XPath memory leak, node comparison error
  * HTML parser autoclose stack usage
  * various regexp fixes
  * htmlCtxtReset fix
  * invalid char in text XInclude
  * and many more ... see NEWS
- dropped obsoleted patches:
  * null-retval.patch (included in update)
* Mon Apr  2 2007 rguenther@suse.de
- add zlib-devel BuildRequires
* Thu Jan 25 2007 prusnak@suse.cz
- fixed crash on ENOMEM (null-retval.patch) [#215223]
* Tue Jan  9 2007 sbrabec@suse.cz
- gnomeprefix changed to /usr.
- Removed obsolete PreReq.
* Mon Dec 11 2006 ke@suse.de
- 2.6.27; many improvements and bug fixes.  For details, see the NEWS
  file.
- Remove libxml2-xpath-1.318.patch (obsolete).
* Tue Oct 17 2006 ke@suse.de
- Move manpage to devel subpackage; reported by Andreas Hanke [#
  212441].
* Tue Aug 15 2006 ke@suse.de
- Remove left-over SuSEconfig traces in %%files list.
* Mon Aug 14 2006 ke@suse.de
- Remove SuSEconfig related files completely.  /etc/xml/catalog is now
  provided by the sgml-skel package.
* Wed Jun 28 2006 ke@suse.de
- Once the catalog is initialized, remove the SuSEconfig trigger
  file; reported by Stanislav Brabec [# 188885].
* Tue Jun 27 2006 ke@suse.de
- Apply libxml2-xpath-1.318.patch from CVS: Do not return too many
  nodes.
* Fri Jun 16 2006 ke@suse.de
- 2.6.26; NEWS extract from http://xmlsoft.org/ :
  * Bug fixes: encoding buffer problem, mix of code and data in xmlIO.c,
    entities in XSD validation, various XSD validation fixes, memory leak
    in pattern, attribute with colon in name, XPath leak inerror
    reporting, XInclude text include of selfdocument.
  * Xpath optimizations.
* Tue May 16 2006 ke@suse.de
- 2.6.24; NEWS extract from http://xmlsoft.org/ :
  * Improvements: XML catalog debugging; update to Unicode 4.01.
  * Bug fixes: xmlParseChunk() problem in 2.6.23,
    xmlParseInNodeContext() on HTML docs, comment streaming bug
    xmlParseComment, regexp bug fixes, xmlGetNodePath on text/CDATA, one
    Relax-NG interleave bug, XSD bugfixes, etc.
  * Documentation: man pages updates and cleanups
  * New features:
  - Relax NG structure error handlers.
  - xmlDOMWrapReconcileNamespaces xmlDOMWrapCloneNode.
- libxml2-python-whitespace.diff: Remove it, obsolete.
* Fri Feb 17 2006 kukuk@suse.de
- Don't install binaries in doc [#151897]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 ke@suse.de
- libxml2-python-whitespace.diff: Fix inconsistent use of tabs and
  spaces in indentation in libxml2.py.  Reported by Christoph Thiel;
  thanks to Jan Matejek [# 143082].
* Mon Jan  9 2006 ke@suse.de
- Update to version 2.6.23; NEWS extract from http://xmlsoft.org/ :
  * Bug fixes (leaks, XPath, validation issue, etc.).
  * Improvements (XSD Schemas redefinitions/restrictions, node copy
    checks and fix for attribute, handle gzipped HTTP resources, etc.).
  * Documentation.
* Wed Dec 21 2005 aj@suse.de
- Package /usr/include/libxml in -devel package.
* Fri Sep 16 2005 ke@suse.de
- Update to version 2.6.22; NEWS from http://xmlsoft.org/  (extract
  since .21):
  * Bug fixes (too many to list here).
  * Improvements on interfaces for schemas and RNG error reports.
  * Optimization of the char data inner loop parsing.
  * More lax mode for the HTML parser.
  * XML Schemas improvements preparing for derive (Kasimier Buchcik).
- libxml2-printf.patch: Adjust it.
- xml-error-handling.patch: Obsolete.
* Thu Jul 28 2005 ke@suse.de
- Fix error handling.  Reported by Michael Radziej, apply fix from CVS
  as proposed by JP Rosevear [# 98487].
* Mon Jul 11 2005 ke@suse.de
- Update to version 2.6.20; NEWS from
  http://xmlsoft.org/:
  * Major improvement in XSD Schemas.
  * XSD Schemas streaming support (SAX and Reader), flagged as somewhat
    experimental.
  * New DOM importing functions
  * Various build and bug fixes, including memory leaks; for details
    check the NEWS file.
* Wed Apr  6 2005 meissner@suse.de
- make build again on gcc >= 4, added parallel make.
* Mon Apr  4 2005 ke@suse.de
- Update to version 2.6.19; NEWS (extract since .18) from
  http://xmlsoft.org/:
  * Bugfixes: xmlSchemaElementDump namespace, push and xmlreader
    stopping on non-fatal errors, thread support for dictionnaries
    reference counting, internal subset and push problem, URL saved in
    xmlCopyDoc, various schemas bug fixes, Python paths fixup,
    xmlGetNodePath and namespaces, xmlSetNsProp fix, warning should not
    count as error, xmlCreatePushParser empty chunk, XInclude parser
    flags, xmlTextWriterStartAttributeNS fix, xmlWriter bugs,
    xmlSearchNsByHref fix, Python binding leak, aliasing bug exposed by
    gcc4 on s390, xmlTextReaderNext bug, Schemas decimal type fixes,
    xmlByteConsumed static buffer, schemas type decimal fixups, xmmlint
    return code, workaround "DAV:" namespace brokeness in c14n segfault
    in Schemas, Schemas attribute validation, Prop related functions and
    xmlNewNodeEatName, HTML serialization of name attribute on a
    elements, Python error handlers leaks and improvement, Relax-NG
    validation bug, xmlSAXParseDoc and xmlParseDoc signatures, switched
    back to assuming UTF-8 in case no encoding is given at serialization
    time.
  * improvement: speedup parsing comments and DTDs, dictionnary support
    for hash tables, Schemas Identity constraints, streaming XPath
    subset, xmlTextReaderReadString added, Schemas canonical values
    handling, add xmlTextReaderByteConsumed, add a --nodict mode to
    xsltproc to check problems for documents without dictionnaries.
* Fri Apr  1 2005 meissner@suse.de
- disable visibility hacks for gcc >= 4
* Mon Jan 24 2005 meissner@suse.de
- specify printf format attributes to check for bad format string use.
* Mon Jan 17 2005 ke@suse.de
- Update to version 2.6.17; NEWS (extract) from http://xmlsoft.org/:
  * Bug fixes:
    xmlTextReaderHasAttributes, xmlCtxtReadFile() to use the catalog(s),
    loop on output, XPath memory leak, ID deallocation problem,
    xmlStopParser bug, UTF-16 with BOM on DTDs, namespace bug on empty
    elements in push mode, line and col computations fixups,
    xmlURIEscape fix, xmlXPathErr on bad range, patterns with too many
    steps, and more.
  * Improvements:
    XSD Schemas, python generator, xmlUTF8Strpos speedup, Python __str__
    call serialize(), and more.
  * New APIs:
    Add xmlDictExists(), GetLineNumber and GetColumnNumber for the
    xmlReader, Dynamic Shared Libraries APIs, error extraction API from
    regexps, and new XMLSave option for format.
  * Documentation improvements.
* Thu Nov 11 2004 ke@suse.de
- Update to version 2.6.16; NEWS (extract) from http://xmlsoft.org/:
  * Important bug fix release, it also fixes main bugs raised against
    2.6.15 and memory leaks found by automated testing of the API.
  * Documentation update.
  * Provide DTD validation APIs at the Python level.
* Thu Oct 28 2004 ke@suse.de
- Update to version 2.6.15; NEWS (extract) from http://xmlsoft.org/:
  * Security fixes on the nanoftp and nanohttp modules:
    http://www.securityfocus.com/archive/1/379383/2004-10-24/2004-10-30/0
  * Bug fixes: HTML parser on broken ASCII chars in names, Python paths,
    xmlHasNsProp and default namespace, DTD lookup fix, save back
    <group> in catalogs, tree build fixes, Schemas memory bug and
    another memory leak, xmlValidateDtd in the presence of an internal
    subset, entities and _private problem, xmlBuildRelativeURI error,
    and more.
  * Improvements: Better XInclude error reports, tree debugging module
    and tests, convenience functions at the Reader API, add support for
    PI in the HTML parser.
* Thu Oct  7 2004 ke@suse.de
- Update to version 2.6.14; NEWS since version 2.6.13:
  * Fix and cleanup XML schemas,
    UTF-8 issues, fix default namespace problem,
    encoding error could genrate a
    serialization loop, XInclude testing, Notation serialization, and
    other bugs.
  * Improveme schemas validity, added --path and --load-trace options to
    xmllint.
  * Enhance Python support.
  * Documentation: tutorial update.
- Drop obsolete NS patch.
* Tue Sep  7 2004 ke@suse.de
- libxml2-default-ns.patch: Fix problem with namespaces; provided by
  William M. Brack [# 44214].
* Mon Aug 23 2004 ke@suse.de
- Update to version 2.6.12; NEWS (extract) from http://xmlsoft.org/:
  * Better XSD Schemas support.
  * Python binding improvements
  * Enhancement of command line tools.
  * Documentation fixes.
  * Various bug fixes (RVT, XPath context resets bug, catalog white
    space handling, xmlReader state after attribute reading, out of
    Memory conditions handling, htmlNewDoc() charset, notation
    serialization, etc.).
* Wed Jul 21 2004 bg@suse.de
- disable elfgcchack for hppa to produce working binaries.
* Wed Jul 14 2004 ke@suse.de
- Update to version 2.6.11; NEWS (extract) from http://xmlsoft.org/:
  * Bugfixes and improvements to XML Schemas support.
  * Update to the documentation tutorial and man pages.
  * Bugfixes:
    C14N bug serializing namespaces, empty node set in XPath, XInclude
    xml:base generation, XInclude fallback problem, XPointer and
    xml:base problem, Reader and entities, xmllint related fixes, DTD
    serialization problem xmlReader fixes, Python bindings improvement,
    fix the push parser, URI escaping and filemanes, XHTML1 formatting,
    reverse xmlEncodeSpecialChars() behaviour back to escaping '"', etc.
  * improvements:
    custom per-thread I/O enhancement, dynamically increase the number
    of XPath extension functions in Python and fix a memory leak,
    make xmlTextReaderMode public,
  * Increase performance.
* Mon Apr 19 2004 ke@suse.de
- Update to version 2.6.9; NEWS (extract) from http://xmlsoft.org/:
  * implement xml:id Working Draft, relaxed XPath id() checking.
  * bugfixes: xmlCtxtReset, line number and CDATA, Regexp patches,
    xmlUriEscape, Relax-NG bugs, XInclude duplicate
    fallback, external DTD encoding detection, a DTD
    validation bug, xmlReader Close() fix, recusive extention
    schemas.
  * various improvements an performance patches.
  * documentation fixes.
- Remove obsolete patches (libxml2-parser.patch,
  libxml2-xpath-memleak.patch, libxml2-nanohttp-fd-close.patch).
* Wed Mar 24 2004 ke@suse.de
- libxml2-nanohttp-fd-close.patch: add a close for the local file
  descriptor by William Brack (from libxml2 CVS).
- libxml2-xpath-memleak.patch: fix a memory leak (xmlXPathLangFunction)
  by William Brack (from libxml2 CVS); reported by Mike Hommey.
* Thu Mar 18 2004 ke@suse.de
- Do not install pre-compiled examples; reported by Dirk Mueller [#
  36382].
* Thu Mar 11 2004 ke@suse.de
- Fix memory leak in parser.c.  Patch by Daniel Veillard (from libxml2
  CVS), reported by Holger Rauch.
* Tue Feb 24 2004 ke@suse.de
- Update to version 2.6.7; NEWS (extract) from http://xmlsoft.org/:
  Mostly small bugfixes and performances improvements:
  * Documentation: tutorial updates.
  * xmlWriter: updates and fixes.
  * XPath optimization.
  * DTD ID handling optimization.
  * Python: 2.3 compatibility, whitespace fixes.
  * Add relaxng option to xmllint --shell .
- Add -fno-strict-aliasing to CFLAGS.
* Mon Feb 23 2004 ke@suse.de
- Support C++ exceptions; reported by Ulrich Heinen [# 34865].
* Thu Feb 19 2004 ke@suse.de
- libxml2-id-idref-validation.patch: Remove a non-linear behaviour from
  ID/IDREF by Daniel Veillard (from libxml2 CVS).
* Fri Feb 13 2004 ke@suse.de
- Update to version 2.6.6; NEWS (extract) from http://xmlsoft.org/:
  Mostly a bug fixes including potentially dangerous buffer overflows
  discovered in the FTP and HTTP URL parsing code (historical it was
  written before the module uri.c, ideally that code should now be
  dropped); also a couple of minor API enhancements:
  * nanohttp and nanoftp: buffer overflow error on URI parsing.
  * bugfixes: make test and path issues, xmlWriter attribute
    serialization, xmlWriter indentation , schemas validation, XInclude
    dictionnaries issues, XInclude empty fallback, HTML warnings,
    XPointer in XInclude, Python namespace serialization, isolat1ToUTF8
    bound error, output of parameter entities in internal subset,
    internal subset bug in push mode, <xs:all> fix.
  * XInclude: allow the 2001 namespace without warning.
  * reader API: structured error reporting
  * Parsers: added xmlByteConsumed(ctxt) API to get the byte offest in
    input.
* Mon Jan 26 2004 ke@suse.de
- Update to version 2.6.5; NEWS (extract) from http://xmlsoft.org/:
  * Bugfixes: dictionnaries for schemas, regexp segfault, xs:all
    problem, a number of XPointer bugfixes, xmllint error go to stderr,
    DTD validation problem with namespace, memory leak, SAX1 cleanup and
    minimal options fixes, parser context reset on error, XPath union
    evaluation problem, xmlReallocLoc with NULL, XML Schemas double
    free, XInclude with no href, argument callbacks order for XPath
    callbacks.
  * Documentation enhancements.
  * Python bindings: fixes, enum support, structured error reporting,
    problem related to dictionnary references, recursion.
  * xmlWriter: indentation, memory leaks.
  * xmlSchemas: normalizedString datatype.
  * Parser optimizations, a few new XPath and dictionnary APIs for
    future XSLT optimizations.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Jan  9 2004 adrian@suse.de
- add %%run_ldconfig to %%postun
* Wed Jan  7 2004 ke@suse.de
- Update to version 2.6.4; NEWS (extract) from http://xmlsoft.org/:
  * Fix serious XInclude problems.
  * Documentation improvements.
  * example fix (Lucas Brasilino)
  * Various bugfixes: xmlTextReaderExpand() with xmlReaderWalker,
    XPath handling of NULL strings, API building reader or parser
    from filedescriptor should not close it, changed XPath
    sorting to be stable again, xmlGetNodePath() generating
    '(null)', DTD validation and namespace bug,
    XML Schemas double inclusion behaviour.
* Thu Dec 11 2003 ke@suse.de
- Update to version 2.6.3; NEWS (extract) from http://xmlsoft.org/:
  Cleanup release (documentation, small bug fixes and enhancements).
  Upgrade XInclude support to the latest draft; this includes namespace
  changes (in case of XInclude warnings, you must fix your documents).
  * Add a repository of examples.
  * Unicode range checking.
  * UTF-16 cleanup and BOM issues.
  * Bug fixes: ID and xmlReader validation, XPath, xmlWriter, hash.h
    inclusion problem, HTML parser, attribute defaulting and validation,
    some serialization cleanups, XML_GET_LINE macro, memory debug when
    using threads, serialization of attributes and entities content,
    xmlWriter.
  * XInclude bugfix, new APIs and update to the last version including
    the namespace change.
  * XML Schemas improvements.
  * Preliminary pattern support for streaming.
- Drop obsolete patch (libxml2-2.6.2-include.patch).
* Wed Nov 12 2003 ke@suse.de
- For libxml2-devel require zlib-devel and readline-devel; reported by
  Tobias Reif.
* Fri Nov  7 2003 ro@suse.de
- change include file hash.h
  define types used in parser.h before including
* Wed Nov  5 2003 ke@suse.de
- Update to version 2.6.2; NEWS (extract) from http://xmlsoft.org/:
  * API additions (should still be API and ABI compatible) and
  performance gains.
  * API to screate a W3C Schemas from an existing document.
  * Deactivate the broken docBook SGML parser code and plug the XML
    parser instead.
  * Enable IPv6 support.
  * Switch to a SAX2 like parser rewrote most of the XML parser core,
    provides namespace resolution and defaulted attributes, minimize memory
    allocations and copies, namespace checking and specific error handling,
    immutable buffers, make predefined entities static structures, etc...
  * Schemas: base64 support.
  * Parser<->HTTP integration fix, proper processing of the Mime-Type
    and charset informations if available.
  * Relax-NG: bug fixes.
  * Documentation fixes.
  * Bug fixes: xmlCleanupParser, threading uninitialized mutexes, HTML
    doctype lowercase, SAX/IO, compression detection and restore,
    attribute declaration in DTDs, namespace on attribute in HTML output,
    input filename, namespace DTD validation, xmlReplaceNode, I/O
    callbacks, CDATA serialization, xmlReader, high codepoint charref
    like &#x10FFFF;, buffer access in push mode, XPath bug,
    xmlCleanupParser, CDATA output, HTTP error handling.
    Mandatory encoding in text decl, serializing Document Fragment
    nodes,
    XPath context unregistration fixes, text node coalescing fixes,
    stdin parsing fix, a posteriori DTD validation fixes and other fixes.
  * xmllint options: --dtdvalidfpi, --sax1 for compat testing, --nodict
    for building without tree dictionnary, --nocdata to replace CDATA by
    text, --nsclean to remove surperfluous namespace declarations.
  * Always generate line numbers when using the new xmlReadxxx functions
  * Add XInclude support to the xmlReader interface.
  * Implement XML_PARSE_NONET parser option.
  * DocBook XSLT processing bug fixed.
  * HTML serialization for <p> elements.
  * XPointer failure in XInclude are now handled as resource errors.
  * Fix xmllint --html to use the HTML serializer on output (add --xmlout
    to implement the previous behaviour of saving it using the XML
    serializer).
* Tue Oct  7 2003 ke@suse.de
- Update to version 2.5.11:
  * Fix bug in Relax-NG.
  * Fix crash when using multithreaded programs.
* Fri Aug 29 2003 kukuk@suse.de
- Add %%verify tag to /var/adm/SuSEconfig/run-libxml2
* Wed Aug 27 2003 ke@suse.de
- Add readline-devel to neededforbuild and enable history/readline
  support for xmllint; proposed by Thomas Schreitle.
* Fri Aug 15 2003 ke@suse.de
- Update to version 2.5.10; NEWS from http://xmlsoft.org/:
  * Bugfixes: UTF-16 support, HTML parser, xmlSAXParseDTD().
  * Improve XInclude performance problem
  * Improve XML parser performance.
* Thu Aug 14 2003 ke@suse.de
- Update to version 2.5.9; NEWS from http://xmlsoft.org/:
  * Bugfixes: IPv6 portability, xmlHasNsProp, Schemas, threading,
    hexBinary type, UTF-16 BOM, xmlReader, namespace handling, EXSLT, HTML
    parsing problem, DTD validation for mixed content + namespaces,
    HTML serialization, library initialization, progressive HTML parser.
  * Better interfaces for Relax-NG error handling.
  * Add xmlXIncludeProcessTree() for XInclud'ing in a subtree.
  * Doc fixes and improvements.
  * New UTF-8 helper functions.
  * General encoding cleanup + ISO-8859-x without iconv.
  * xmlTextReader cleanup + enum for node types.
* Tue Jul  8 2003 ke@suse.de
- Update to version 2.5.8; NEWS from http://xmlsoft.org/:
  * Bugfixes: XPath, XInclude, file/URI mapping, UTF-16 save, UTF-8
    checking, URI saving, error printing, PI related memleak,
    compilation without schemas or without xpath, xmlUnlinkNode problem
    with DTDs, xmlIOParseDTD, and xmlSAXParseDTD.
  * Fix multithreading lock problems.
  * IPv6 patch for FTP and HTTP accesses.
  * A few W3C Schemas Structure improvements.
  * W3C Schemas Datatype improvements.
  * Python bindings for thread globals, and method/class generator.
  * Add --nonet option to xmllint.
  * Documentation improvements.
- libxml2-2.5.8-mutex.patch provided by Daniel Veillard.
* Thu Jun 12 2003 kukuk@suse.de
- Add gnome directories to filelist
* Mon May 26 2003 ke@suse.de
- Remove unwanted files from $RPM_BUILD_ROOT.
* Mon Apr 28 2003 ke@suse.de
- Update to version 2.5.7; NEWS from http://xmlsoft.org/:
  * Relax-NG: Compiling to regexp and streaming validation on top of
    the xmlReader interface, add --stream to xmllint.
  * xmlReader: Expand(), Next() and DOM access glue, bug fixes.
  * Support for large files: RGN validated a 4.5GB instance.
  * Thread support is now configured in by default.
  * Fixes: update of the Trio code, WXS Date and Duration fixes, DTD
    and namespaces,
    HTML push parser and zero bytes handling, behaviour of the parser
    and validator in the presence of "out of memory" error conditions.
  * Extend the API to be able to plug a garbage collecting memory
    allocator, add xmlMallocAtomic() and modified the allocations
    accordingly.
  * Performances: remove excessive malloc() calls, speedup of the
    push and xmlReader interfaces, remove excessive thread locking.
  * Documentation: man page, xmlReader documentation
  * Python: add binding for xmlCatalogAddLocal.
* Wed Apr  2 2003 ke@suse.de
- Update to version 2.5.6; NEWS from http://xmlsoft.org/:
  * Fix W3C XML Schemas datatype, should be compliant now except
    for binHex and base64 which are not supported yet.
  * Bug fix: non-ASCII IDs, HTML output, XInclude on large docs and
    XInclude entities handling, encoding detection on external subsets,
    XML Schemas bugs and memory leaks, HTML parser.
  * improved error reporting: xml:space, start/end tag mismatches, Relax
    NG errors.
- Frop obsolete trio patch.
* Wed Mar 26 2003 ke@suse.de
- Update to version 2.5.5; NEWS from http://xmlsoft.org/:
  * Fixes on the Relax NG implementation.
  * Increase support for W3C XML Schemas datatype.
  * Bug fixes in the URI handling layer.
  * Bug fixes: HTML parser, xmlReader, DTD validation, XPath, encoding
  conversion, line counting in the parser.
  * Add support for $XMLLINT_INDENT environment variable, FTP delete.
- Apply patch by Albert Chin to enable use of trio libraries in Python.
* Thu Feb 20 2003 ke@suse.de
- Add /usr/bin/install to PreReq; reported by Thorsten Kukuk
  [# 23891].
* Tue Feb 11 2003 ke@suse.de
- Update to version 2.5.3; NEWS from http://xmlsoft.org/:
  A bugfix release.  Relax-NG and XML Schemas datatypes stabilization:
  * RelaxNG and XML Schemas datatypes improvements; first version of
    RelaxNG Python bindings.
  * Fixes: XLink, XInclude, API fix for serializing namespace nodes,
    encoding conversion bug, XHTML1 serialization.
* Thu Feb  6 2003 ro@suse.de
- fix specfile
* Thu Feb  6 2003 ke@suse.de
- Update to version 2.5.2; NEWS from http://xmlsoft.org/:
  First release with the RelaxNG validation code.  Schemas support is
  also configured in by default now. All this code is still of alpha
  quality.
  This release also includes a number of fixes and some API improvements:
  * First implementation of RelaxNG, added --relaxng flag to xmllint.
  * Schemas support now compiled in by default.
  * Bug fixes: DTD validation, namespace checking, XInclude and entities,
    delegateURI in XML Catalogs, HTML parser, XML reader, XPath parser
    and evaluation, UTF8ToUTF8 serialization, XML reader memory
    consumption, HTML parser, HTML serialization in the presence of
    namespaces.
  * Add an HTML API to check elements and attributes.
  * Documentation improvement.
  * Add python bindings for XPointer, contextual error reporting.
  * Fix URI/file escaping problems.
- Remove obsolete README.SuSE.
* Thu Jan  9 2003 ke@suse.de
- Update to version 2.5.1; NEWS from http://xmlsoft.org/:
  * New XmltextReader interface based on C# API;
    cf. http://xmlsoft.org/xmlreader.html .
  * XInclude fallback fix.
  * Python: bindings for the new API, packaging, drv_libxml2.py Python
    xml.sax driver, fixes, speedup and iterators for Python-2.2.
  * Tutorial fixes, xmllint man update.
  * Fix an XML parser bug.
  * Entities handling fixes
  * new API to optionally track node creation and deletion.
  * Added documentation for the XmltextReader interface and some XML guidelines
* Thu Dec 12 2002 ke@suse.de
- Update to version 2.4.30; NEWS from http://xmlsoft.org/:
  * Main changes are the addition of a new API set closely based on
    the C#/ECMA-334 XmlTextReader interface, allowing to scan an XML
    document in a forward only way but in (near) constant memory size.
  * Fix for prev in python bindings.
  * Fix for entities handling (Marcus Clarke), replacing patch from
    2002-12-02.
  * Refactor the XML and HTML dumps to a single code path, fix XHTML1
    dump.
  * Fix for URI parsing when handling URNs with fragment identifiers
  * Fix for HTTP URL escaping problem.
  * Adde an TextXmlReader (C#) like API (work in progress).
  * Rewrote the API in XML generation script, includes a C parser and saves
    more informations needed for C# bindings.
* Mon Dec  2 2002 ke@suse.de
- Fix "Entity in Entity processing"; patch provided by DV.
  Cf. [# 22208].
* Tue Nov 26 2002 ro@suse.de
- split libxml2-python to own specfile
  (libxml2 is turning more and more into a base package
  and python requires a lot of other things to build)
* Mon Nov 25 2002 ke@suse.de
- Update to version 2.4.28; NEWS from http://xmlsoft.org/:
  * Fix a couple of python binding bugs.
  * Fix 2 bugs in the XML push parser.
  * Remove potential memory leak.
  * Add encoding support for XInclude parse="text".
  * Autodetect XHTML1 and add specific serialization rules.
  * Fix threading bug.
* Mon Nov 18 2002 ke@suse.de
- Update to version 2.4.27; NEWS from http://xmlsoft.org/:
  * Fix Python bindings.
  * A number of bug fixes: SGML catalogs, xmlParseBalancedChunkMemory(),
    HTML parser, Schemas, document fragment support, xmlReconciliateNs,
    XPointer, xmlFreeNode(), xmlSAXParseMemory, xmlGetNodePath,
    entities processing.
  * Add grep to xmllint --shell.
  * Improvement documentation.
- Don't apply obsolete revert-.25-.26.dif patch.
* Mon Nov  4 2002 adrian@suse.de
- revert catalog separator change, accepting ":" again.
  libxml2 is using anyway ":" internal, even when a " " separator
  is given
* Thu Oct 31 2002 ro@suse.de
- removed patch call for removed patch
* Wed Oct 30 2002 ke@suse.de
- Drop libxml2-2.4.19-xml2-config.dif to avoid header file conflicts
  with C++; reported by Andreas Mueller [# 21427].
* Tue Oct 29 2002 ke@suse.de
- Update to version 2.4.26; NEWS from http://xmlsoft.org/:
  * Fix the validation code (DTD and Schemas), xmlNodeGetPath() ,
  HTML serialization, Namespace compliance, and a number of small
  problems.
- "valid" patches are obsolete with his update.
* Fri Oct 11 2002 ke@suse.de
- valid.c: Fix uninitialized memory block (patch by Daniel Veillard).
* Tue Oct  8 2002 ke@suse.de
- Update to version 2.4.25; NEWS from http://xmlsoft.org/:
  * A number of bug fixes: XPath, validation, DOM and tree, XML I/O,
    HTML.
  * Fix and improve Python bindings.
  * Fix HTML <style> and boolean attributes serializer.
  * Improve C14N.
  * Cleanup docs.
  * Serious rewrite of XInclude.
  * Make XML Schemas regexp part of the default build and APIs, small
    fixes and improvement of the regexp core
  * Change the validation code to reuse XML Schemas regexp APIs
  * Tutorial improvements.
  * Remove of all stderr/perror use for error reporting
  * Better error reporting: XPath and DTD validation
  * Update of the trio portability layer (Bjorn Reese)
- spec file: don't delete package files in %%post; change test in
  SuSEconfig.libxml2 accordingly [# 20028].
* Fri Aug 23 2002 ke@suse.de
- Move SuSEconfig.libxml2 from the devel subpackage to the main package
  and check for "/etc" instead of "etc".
  Partly fix for [# 17646].
* Tue Aug  6 2002 ke@suse.de
- Add a PreRequires for zlib [Bug# 17436].
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Mon Jul  8 2002 ke@suse.de
- Update to version 2.4.23; NEWS from http://xmlsoft.org/, not mentioned
  earlier:
  - Bug fixes: base handling, parser, memory usage, HTML parser, XPath,
    documentation (Christian Cornelssen), indentation, URI parsing.
  - Optimizations for XMLSec; fix and make public some of the network
    protocol handlers.
  - Date and time support for XML Schemas datatypes.
* Tue May 28 2002 ro@suse.de
- tweak python installation for lib64 some more
* Tue May 28 2002 ke@suse.de
- Fix python installation procedure (thanks to Ruediger Oertel and
  Stefan Fent).
* Tue May 28 2002 ke@suse.de
- Update to version 2.4.22:
  - Bug fixes.
  - Increase performance.
* Tue May  7 2002 ke@suse.de
- Create /etc/xml/catalog via SuSEconfig (don't rely on %%post).
  Rported by Petr Ostadal [# 16115].
- Don't claim to own /etc/xml/catalog; thus don't delete it via
  %%postun).
* Thu May  2 2002 ke@suse.de
- Build and install python module as an own subpackage.
- Create initial XML catalog (/etc/xml/catalog).
* Tue Apr 30 2002 ke@suse.de
- Update to version 2.4.21; NEWS from http://xmlsoft.org/:
  This release is both a bug fix release and also contains the early
  XML Schemas structures and datatypes code, beware, all interfaces are
  likely to change, there is huge holes, it is clearly a work in
  progress and don't even think of putting this code in a production
  system, it's actually not compiled in by default.
  The real fixes are:
  o A couple of bugs or limitations introduced in 2.4.20.
  o Fixes on XPath strings and conformance patches.
  o Patch for the ExcC14N specification.
* Fri Apr 19 2002 ke@suse.de
- Update to version 2.4.20; NEWS from http://xmlsoft.org/:
  o Bug fixes: File descriptor leak, XPath, HTML ouput, DTD
    validation.
  o XPath conformance testing by Richard Jinks.
  o Improve Python bindings.
* Tue Apr  9 2002 ro@suse.de
- also provide /usr/include/libxml2/libxml in "xml2-config --cflags"
* Tue Apr  9 2002 ke@suse.de
- Update to version 2.4.19; NEWS since 2.4.13 from http://xmlsoft.org/:
  * Change of Licence to the MIT Licence basisally for integration in
    XFree86 codebase, and removing confusion around the previous
    dual-licencing.
  * Bug fixes: XPath bugs, validation, ISO-Latin to UTF8 encoder,
    tree, SAX, canonicalization, bug "namespace nodes have no parents
    in XPath".
  * Bug fixes: bugs triggered by the XML Testsuite from OASIS and
    W3C. Compliance has been significantly improved.
  * Memory allocation checks using valgrind, and profiling tests
  * Speedup patch to XPath very effective for DocBook stylesheets
  * Add XML Canonalization support.
  * Add xmlSetEntityReferenceFunc() for Keith Isdale work on xsldbg.
  * Add Python bindings.
  * Cleanup of the headers, generation of a reference API definition in XML
  * Cleanup of timing code.
  * Update documentation.
* Mon Feb 11 2002 coolo@suse.de
- use %%_lib and %%_libdir
* Mon Jan 14 2002 hhetter@suse.de
- updated to version 2.4.12
  * a few bug fixes: thread,  xmllint , XML parser
  XPointer , I/O cleanups
  * portability improvements
  * some makefiles cleanups
* Tue Nov 27 2001 ke@suse.de
- Update to version 2.4.11; NEWS from http://xmlsoft.org/ (include some
  items not mentioned earlier):
  - Fix errors and bug (mostly include files related).
  - Fix URI escaping, namespace handling problems when using DTD and
    validation, paths or XPointers generation.
  - Improve xmllint.
  - Fix HTML parser.
* Sun Nov 11 2001 adrian@suse.de
- Update to version 2.4.10:
  - Bugfix / Cleanup release.
* Wed Nov  7 2001 ke@suse.de
- Update to version 2.4.9:
  - Fix XML and SGML catalog handling.
- Drop libxml2-makefile-am.diff; is obsolete.
* Mon Nov  5 2001 ke@suse.de
- Update to version 2.4.8; NEWS from http://xmlsoft.org/:
  - Fix SGML catalog support.
  - Update xmlcatalog tool.
- Apply libxml2-makefile-am.diff on account of automake 1.5 (multiply
  set variables).
* Wed Oct 31 2001 ke@suse.de
- Update to version 2.4.7; NEWS from http://xmlsoft.org/:
  - Serious rewrite of the catalog code.
  - Integrate thread safety patch.
  - Bug fixes: HTML parser, potentially serious validation issues and
    general bug fixes.
  - Integrate the SGML DocBook support in xmllint; update manpage.
  - Change nanoftp anonymous login passwd.
  - Some I/O cleanup and a couple of interfaces for Perl wrapper.
* Thu Oct 11 2001 ke@suse.de
- Compatibility link for SuSE Linux 7.3 and earlier:
  /usr/include/libxml -> libxml2/libxml
  (will go away on version 8.0); cf. [#11709].
- Add README.SuSE.
* Thu Oct 11 2001 ke@suse.de
- Update to version 2.4.6; NEWS from http://xmlsoft.org/:
  - Add and update man pages.
  - Portability and configure fixes.
  - Fix an infinite loop on the HTML parser.
  - Fix half a dozen bugs reported for libxml or libxslt.
  - Update xmlcatalog to be able to modify SGML super catalogs.
- Note, starting with 2.4.5 includes were moved to
  /usr/lib/libxml2/libxml; use 'xml2-config' to locate these files
  (cf. http://mail.gnome.org/archives/xml/2001-October/msg00069.html)
  [#11709].
* Mon Oct  1 2001 ke@suse.de
- Update to version 2.4.5; NEWS from http://xmlsoft.org/ :
  - Bugfixes and some portability changes.
  - Force the HTML serializer to output decimal charrefs since some
    version of Netscape can't handle hexadecimal ones.
  - Add --convert to xmlcatalog, bug fixes and cleanups of XML Catalog.
  - Some documentation cleanups.
- Drop obsolete configure patch.
* Fri Aug 24 2001 ke@suse.de
- Update to version 2.4.3; from the announcement (cf. libxslt):
  - Implement XML Catalog Specification from August 6:
    http://www.oasis-open.org/committees/entity/spec-2001-08-06.html
    http://xmlsoft.org/catalog.html
  - New NaN and Infinity code.
  - A number of small bugfixes.
* Fri Aug 17 2001 ro@suse.de
- re-enabled suse_update_config and added autoconf/automake
  sequence.
* Fri Aug 17 2001 ke@suse.de
- Update to version 2.4.2.
- Drop suse_update_config (seems to confuse auto* at the moment).
* Fri Aug 10 2001 kukuk@suse.de
- Revert change to ldconfig call
* Thu Jul 26 2001 ke@suse.de
- Update to version 2.4.1
- Call 'ldconfig' only for UID = 0.
* Wed Jul 11 2001 ke@suse.de
- Update to version 2.4.0.
- Call 'ldconfig' during build (as required by SuSE Package
  Conventions).
* Wed Jul  4 2001 adrian@suse.de
- xml2-config --cflags will not output -I/usr/include anymore
  this causes compilation failures with gcc3 due to the wrong
  include path order
* Fri Jun 29 2001 ke@suse.de
- Update to version 2.3.13.
- Apply libxml2-no-example.diff not to try to compile the "example".
* Mon May 21 2001 ke@suse.de
- Update to version 2.3.9
* Sat Apr 14 2001 adrian@suse.de
- update to 2.3.6
* Fri Feb 23 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Thu Feb 15 2001 ke@suse.de
- Initial package: version 2.3.0 [#2861].
